@@ -9,19 +9,6 @@ Data Ingestion into the Switch Automation
 
 Complete package for ingestion data into the Switch Automation Platform.
 """
-__all__ = [
-    'models',
-    'exceptions',
-    'tasks',
-    'utils',
-    'exceptions',
-    'SwitchGuideTask',
-    'api',
-    'step',
-    'guide',
-    'literals',
-    'enums'
-]
 
 from . import models
 from .models import api
@@ -32,8 +19,22 @@ from .models import literals
 
 from . import exceptions
 from . import tasks
-from . import exceptions
 from . import utils
+from . import extensions
 from .SwitchGuideTask import SwitchGuideTask
 
-__version__ = "0.1.14"
+__all__ = [
+    'models',
+    'exceptions',
+    'extensions',
+    'tasks',
+    'utils',
+    'SwitchGuideTask',
+    'api',
+    'step',
+    'guide',
+    'literals',
+    'enums'
+]
+
+__version__ = "0.1.15"
