@@ -6,7 +6,9 @@
 
 
 from . import utils
+from .utils import ApiInputs
 
 __all__ = [
-    'utils'
+    'utils',
+    'ApiInputs'
 ]
